@@ -22,12 +22,10 @@ const auto configPattern = QStringLiteral("desktop-for-%1");
 const auto kwinName = QStringLiteral("org.kde.KWin");
 const auto kwinPath = QStringLiteral("/KWin");
 
-VirtualDesktopSwitchPlugin::VirtualDesktopSwitchPlugin(QObject *parent, const QVariantList &args)
+VirtualDesktopSwitchPlugin::VirtualDesktopSwitchPlugin(QObject *parent)
     : Plugin(parent)
     , m_activitiesService(nullptr)
 {
-    Q_UNUSED(args);
-
     setName("org.kde.ActivityManager.VirtualDesktopSwitch");
 }
 
@@ -41,7 +39,7 @@ bool VirtualDesktopSwitchPlugin::init(QHash<QString, QObject *> &modules)
 
     m_activitiesService = modules["activities"];
 
-    m_currentActivity = Plugin::retrieve<QString>(m_activitiesService, "CurrentActivity", "QString");
+    m_currentActivity = Plugin::retrieve<QString>(m_activitiesService, "CurrentActivity");
 
     connect(m_activitiesService, SIGNAL(CurrentActivityChanged(QString)), this, SLOT(currentActivityChanged(QString)));
     connect(m_activitiesService, SIGNAL(ActivityRemoved(QString)), this, SLOT(activityRemoved(QString)));
@@ -87,3 +85,5 @@ void VirtualDesktopSwitchPlugin::activityRemoved(const QString &activity)
 }
 
 #include "VirtualDesktopSwitchPlugin.moc"
+
+#include "moc_VirtualDesktopSwitchPlugin.cpp"
